<?php
/* Author: Arthur Furlan */

$labels = array();
$labels['buttonjunk'] = 'Marcar como Spam';
$labels['markasjunk'] = 'Spam';
$labels['buttonnotjunk'] = 'Esta mensagem não é Spam';
$labels['markasnotjunk'] = 'Não Spam';

$messages = array();
$messages['reportedasjunk'] = 'Mensagem marcada como Spam com sucesso';
$messages['reportedasnotjunk'] = 'Mensagem movida para a Caixa da Entrada';

?>