<?php
/* Author: Mārtiņš Dzērve */

$labels = array();
$labels['buttonjunk'] = 'Atzīmēt mēstules';
$labels['markasjunk'] = 'Kā mēstuli';
$labels['buttonnotjunk'] = 'Atzīmēt ne-mēstules';
$labels['markasnotjunk'] = 'Kā ne-mēstule';
$labels['notjunk'] = 'Ne-mēstules';

$messages = array();
$messages['reportedasjunk'] = 'Veiksmīgi ziņots par mēstuli';
$messages['reportedasnotjunk'] = 'Veiksmīgi ziņots par ne-mēstuli';

?>