<?php
/* Author: MASUDA Kazuya */

$labels = array();
$labels['buttonjunk'] = '迷惑メールとして設定';
$labels['markasjunk'] = '迷惑メールとして設定';
$labels['buttonnotjunk'] = 'このメッセージは迷惑メールではありません';
$labels['markasnotjunk'] = '迷惑メール設定を解除';
$labels['notjunk'] = '迷惑メール解除';

$messages = array();
$messages['reportedasjunk'] = '迷惑メールとして設定しました';
$messages['reportedasnotjunk'] = '迷惑メール設定を解除しました';

?>