<?php
/* Author: Philip Weir */

$labels = array();
$labels['buttonjunk'] = 'Mark as junk';
$labels['markasjunk'] = 'As junk';
$labels['buttonnotjunk'] = 'This message is not junk';
$labels['markasnotjunk'] = 'As not junk';
$labels['notjunk'] = 'Not junk';

$messages = array();
$messages['reportedasjunk'] = 'Successfully reported as junk';
$messages['reportedasnotjunk'] = 'Successfully reported as not junk';

?>