<?php
/* Author: Hans Spaans */

$labels = array();
$labels['buttonjunk'] = 'Markeer als spam';
$labels['markasjunk'] = 'Is spam';
$labels['buttonnotjunk'] = 'Dit bericht is geen spam';
$labels['markasnotjunk'] = 'Geen spam';

$messages = array();
$messages['reportedasjunk'] = 'Bericht gemarkeerd als spam';
$messages['reportedasnotjunk'] = 'Bericht verplaatst naar Inbox';

?>