<?php
/* Author: David Garabana Barro */

$labels = array();
$labels['buttonjunk'] = 'Marcar como spam';
$labels['markasjunk'] = 'Es spam';
$labels['buttonnotjunk'] = 'Este mensaje no es spam';
$labels['markasnotjunk'] = 'No es spam';

$messages = array();
$messages['reportedasjunk'] = 'Reportado correctamente como spam.';
$messages['reportedasnotjunk'] = 'Movido a la bandeja de entrada.';

?>