<?php
/* Author: David Garabana Barro */

$labels = array();
$labels['buttonjunk'] = 'Marcar coma correo lixo';
$labels['markasjunk'] = 'É correo lixo';
$labels['buttonnotjunk'] = 'Esta mensaxe non é correo lixo';
$labels['markasnotjunk'] = 'Non é correo lixo';

$messages = array();
$messages['reportedasjunk'] = 'Marcouse correctamente coma correo lixo ';
$messages['reportedasnotjunk'] = 'A mensaxe moveuse a caixa de entrada';

?>