<?php
/* Author: Guillermo Asernitzky */

$labels = array();
$labels['buttonjunk'] = 'Marcar como Spam';
$labels['markasjunk'] = 'Como Spam';
$labels['buttonnotjunk'] = 'Este mensaje no es Spam';
$labels['markasnotjunk'] = 'No es Spam';

$messages = array();
$messages['reportedasjunk'] = 'Reportado como Spam';
$messages['reportedasnotjunk'] = 'Mensaje movido a la bandeja de entrada';

?>