<?php
/* Author: Daniel López */

$labels = array();
$labels['buttonjunk'] = 'Marca com a Spam';
$labels['markasjunk'] = 'És Spam';
$labels['buttonnotjunk'] = 'Aquest missatge no és Spam';
$labels['markasnotjunk'] = 'No és Spam';

$messages = array();
$messages['reportedasjunk'] = 'Reportat conrrectament com spam.';
$messages['reportedasnotjunk'] = 'Missatge mogut a la safata d\'Entrada';

?>