<?php
/* Author: Alessio Cecchi */

$labels = array();
$labels['buttonjunk'] = 'Segnala come Spam';
$labels['markasjunk'] = 'Spam';
$labels['buttonnotjunk'] = 'Questo messaggiono non è Spam';
$labels['markasnotjunk'] = 'Non Spam';
$labels['notjunk'] = 'Non Spam';

$messages = array();
$messages['reportedasjunk'] = 'Segnalato con successo come Spam';
$messages['reportedasnotjunk'] = 'Messaggio spostato in Posta in arrivo';

?>