/**
 * MarkAsJunk2 plugin styles
 */

#messagetoolbar a.markasjunk2,
#messagetoolbar a.markasjunk2Sel,
#messagetoolbar a.markasnotjunk2,
#messagetoolbar a.markasnotjunk2Sel
{
  background-image: url(images/mail_toolbar.png);
}

#messagetoolbar a.markasjunk2,
#messagetoolbar a.markasjunk2Sel
{
  background-position: center -14px;
}

#messagetoolbar a.markasnotjunk2,
#messagetoolbar a.markasnotjunk2Sel
{
  background-position: center -61px;
}

ul.toolbarmenu li a span.markasjunk2,
ul.toolbarmenu li a span.markasnotjunk2,
ul.toolbarmenu li a.markasjunk2 span.cmicon,
ul.toolbarmenu li a.markasnotjunk2 span.cmicon
{
  background-image: url(images/messageactions.png);
}

ul.toolbarmenu li a span.markasjunk2,
ul.toolbarmenu li a.markasjunk2 span.cmicon
{
  background-position: 1px -17px;
}

ul.toolbarmenu li a span.markasnotjunk2,
ul.toolbarmenu li a.markasnotjunk2 span.cmicon
{
  background-position: 1px 5px;
}