<?php
/* Author: */

$labels = array();
$labels['buttonjunk'] = 'Marquer comme spam';
$labels['markasjunk'] = 'Comme spam';
$labels['buttonnotjunk'] = 'Ceci n\'est pas un spam';
$labels['markasnotjunk'] = 'Comme acceptable';

$messages = array();
$messages['reportedasjunk'] = 'Message classé en spam';
$messages['reportedasnotjunk'] = 'Message déplacé dans Inbox';

?>