<?php
/* Author: Denny Lin */

$labels = array();
$labels['buttonjunk'] = '標為垃圾郵件';
$labels['markasjunk'] = '標為垃圾郵件';
$labels['buttonnotjunk'] = '非垃圾郵件';
$labels['markasnotjunk'] = '非垃圾郵件';

$messages = array();
$messages['reportedasjunk'] = '已標為垃圾郵件';
$messages['reportedasnotjunk'] = '已移至收件匣';

?>