<?php
/* Author: Attila Sipos */

$labels = array();
$labels['buttonjunk'] = 'Megkelölés levélszemétként';
$labels['markasjunk'] = 'Levélszemétként';
$labels['buttonnotjunk'] = 'Ez az üzenet nem levélszemét';
$labels['markasnotjunk'] = 'Nem levélszemét';
$labels['notjunk'] = 'Nem levélszemét';

$messages = array();
$messages['reportedasjunk'] = 'Sikeresen jelentve, mint levélszemét';
$messages['reportedasnotjunk'] = 'Az üzenet visszakerült a Érkezett levelekbe';

?>