<?php
/* Author: Peter Zotov */

$labels = array();
$labels['buttonjunk'] = 'Пометить как спам';
$labels['markasjunk'] = 'Как спам';
$labels['buttonnotjunk'] = 'Это сообщение не спам';
$labels['markasnotjunk'] = 'Не спам';
$labels['notjunk'] = 'Не спам';

$messages = array();
$messages['reportedasjunk'] = 'Помечено как спам';
$messages['reportedasnotjunk'] = 'Сообщение перемещено во Входящие';

?>