<?php
/* Author: Rrainer Rhalbmann */

$labels = array();
$labels['buttonjunk'] = 'als Spam markieren';
$labels['markasjunk'] = 'als Spam';
$labels['buttonnotjunk'] = 'Diese Nachricht ist kein Spam';
$labels['markasnotjunk'] = 'kein Spam';
$labels['notjunk'] = 'kein Spam';

$messages = array();
$messages['reportedasjunk'] = 'Erfolgreich als Spam gekennzeichnet';
$messages['reportedasnotjunk'] = 'Nachricht in Posteingang verschoben';

?>