<?php
/* Author: Philip Weir */

$labels = array();
$labels['buttonjunk'] = 'Mark as spam';
$labels['markasjunk'] = 'As spam';
$labels['buttonnotjunk'] = 'This message is not spam';
$labels['markasnotjunk'] = 'As not spam';
$labels['notjunk'] = 'Not spam';

$messages = array();
$messages['reportedasjunk'] = 'Successfully reported as spam';
$messages['reportedasnotjunk'] = 'Successfully reported as not spam';

?>