<?php
/* Author: Martin Frajdl */

$labels = array();
$labels['buttonjunk'] = 'Oznacit jako spam';
$labels['markasjunk'] = 'Jako spam';
$labels['buttonnotjunk'] = 'Tato zpráva není spam';
$labels['markasnotjunk'] = 'Nemí spam';

$messages = array();
$messages['reportedasjunk'] = 'Úspešne hlášeny jako spam';
$messages['reportedasnotjunk'] = 'Úspešne hlášeny jako spam';

?>