<?php
/* Author: KiarasH Mozafari */

$labels = array();
$labels['buttonjunk'] = 'بنجل کن';
$labels['markasjunk'] = 'بنجل';
$labels['buttonnotjunk'] = 'این نامه بنجل نیست';
$labels['markasnotjunk'] = 'بنجل نیست';

$messages = array();
$messages['reportedasjunk'] = 'این نامه با موفقیت به صورت بنجل گزارش داده شد';
$messages['reportedasnotjunk'] = 'نامه به صندق منتقل شد';

?>