<?php
/* Author: Mustafa Icer */

$labels = array();
$labels['buttonjunk'] = 'Spam olarak işaretle';
$labels['markasjunk'] = 'Spam olarak';
$labels['buttonnotjunk'] = 'Bu mesaj Spam değildir';
$labels['markasnotjunk'] = 'Spam değildir';

$messages = array();
$messages['reportedasjunk'] = 'Başarıyla spam olarak bildirildi';
$messages['reportedasnotjunk'] = 'Mesaj, gelen klasörüne taşındı';

?>