<?php
/* Author: Bartosz Mierzwiak */

$labels = array();
$labels['buttonjunk'] = 'Oznacz jako Spam';
$labels['markasjunk'] = 'Jako Spam';
$labels['buttonnotjunk'] = 'Ta wiadomość nie jest Spamem';
$labels['markasnotjunk'] = 'Jako nie Spam';
$labels['notjunk'] = 'Nie Spam';

$messages = array();
$messages['reportedasjunk'] = 'Pomyślnie oznaczono jako Spam';
$messages['reportedasnotjunk'] = 'Wiadomość przeniesiona do Odebranych';

?>