<?php
/* Author: Ovidiu Bica */

$labels = array();
$labels['buttonjunk'] = 'Marcheaza ca spam';
$labels['markasjunk'] = 'Este Spam';
$labels['buttonnotjunk'] = 'Acest mesaj nu este spam';
$labels['markasnotjunk'] = 'Nu este spam';

$messages = array();
$messages['reportedasjunk'] = 'Raportat cu succes ca Spam';
$messages['reportedasnotjunk'] = 'Mesajul a fost mutat in Inbox';

?>